@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: A weighted graph implementation
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 use warnings;
 use strict;
@@ -192,6 +192,28 @@ sub path_cost {
     return $path_cost;
 }
 
+
+
+sub dump {
+    my $self = shift;
+    my $attr = shift || 'weight';
+
+    for my $vertex ( $self->vertices ) {
+        printf "%s vertex: %s %s=%s\n",
+            $vertex->title,
+            $vertex->name,
+            $attr,
+            $self->get_cost($vertex, $attr);
+        for my $edge ( $self->edges ) {
+            next if $edge->from->name ne $vertex->name;
+            printf "\tedge to: %s %s=%s\n",
+                $edge->to->name,
+                $attr,
+                $self->get_cost($edge, $attr);
+        }
+    }
+}
+
 1;
 
 __END__
@@ -206,7 +228,7 @@ Graph::Easy::Weighted - A weighted graph implementation
 
 =head1 VERSION
 
-version 0.06
+version 0.07
 
 =head1 SYNOPSIS
 
@@ -221,15 +243,7 @@ version 0.06
       [0,0,0,0,0], #    "   4      0 "               0
     ]
  );
- for my $vertex ( $gw->vertices ) {
-    printf "vertex: %s weight=%.2f\n",
-        $vertex->name, $gw->get_cost($vertex);
-    for my $edge ( $gw->edges ) {
-        next if $edge->from->name ne $vertex->name;
-        printf "\tedge to: %s weight=%.2f\n",
-            $edge->to->name, $gw->get_cost($edge);
-    }
- }
+ $gw->dump();
 
  my ($lightest, $heaviest) = $gw->vertex_span();
  ($lightest, $heaviest) = $gw->edge_span();
@@ -248,15 +262,7 @@ version 0.06
     $attr,
     '%0.2f'
  );
- for my $vertex ( $gw->vertices ) {
-    printf "%s vertex: %s %s=%s\n",
-        $vertex->title, $vertex->name, $attr, $gw->get_cost($vertex, $attr);
-    for my $edge ( $gw->edges ) {
-        next if $edge->from->name ne $vertex->name;
-        printf "\tedge to: %s %s=%s\n",
-            $edge->to->name, $attr, $gw->get_cost($edge, $attr);
-    }
- }
+ $gw->dump();
 
 =head1 DESCRIPTION
 
@@ -341,6 +347,13 @@ Return the summed weight (or given cost attribute) of the path edges.
 For shortest paths and minimum spanning trees, please see
 L<Graph::Weighted/EXAMPLES>.
 
+=head2 dump()
+
+  $gw->dump()
+  $gw->dump($attr)
+
+Print out the graph showing vertices, edges and costs.
+
 =head1 SEE ALSO
 
 L<Graph::Easy>, the parent of this module
